package com.dky.calculate;


import com.dky.utils.enums.EnergyPriceType;

public class KitchenCookModel {

    /**
     * 计算电厨炊年耗电量
     * @param powerPerUnit 设备功率
     * @param numberOfUnits 设备台数
     * @param annualOperatingHours 电设备年运行时间
     * @return 单台电厨炊的功率<A> * 电厨炊设备台数 * 电设备年运行时间<B>
     */
    public static double calculateAnnualElectricityConsumption(double powerPerUnit, int numberOfUnits, int annualOperatingHours) {
        return powerPerUnit * numberOfUnits * annualOperatingHours;
    }

    /**
     * 计算年运行费用
     * @param powerPerUnit 设备功率
     * @param numberOfUnits 设备台数
     * @param annualOperatingHours 电设备年运行时间
     * @param laborCostForReplacement 电替代设备人工费用成本
     * @return 电厨炊年耗电量 *平均电价(0.55元/千瓦时) + 电替代设备人工费用成本<A>
     */
    public  double calculateAnnualOperatingCost(double powerPerUnit, int numberOfUnits, int annualOperatingHours, double laborCostForReplacement) {
        return calculateAnnualElectricityConsumption(powerPerUnit, numberOfUnits, annualOperatingHours) * EnergyPriceType.Residential_Electric_Price.getPrice() + laborCostForReplacement;
    }

    /**
     * 计算总年费用
     * @param numberOfUnits 电厨炊设备台数
     * @param pricePerUnit 单台电设备价格
     * @param usefulLifeYears 电厨炊的使用年限
     * @param powerPerUnit 设备功率
     * @param annualOperatingHours 电设备年运行时间
     * @param laborCostForReplacement 电替代设备人工费用成本
     * @return (电厨炊设备台数 *单台电设备价格<A>）/电厨炊的使用年限<A> + 年运行费用
     */
    public  double calculateTotalAnnualCost(int numberOfUnits, double pricePerUnit, int usefulLifeYears, double powerPerUnit, int annualOperatingHours, double laborCostForReplacement) {
        double initialCost = numberOfUnits * pricePerUnit;
        double depreciationCost = initialCost / usefulLifeYears;
        return depreciationCost + calculateAnnualOperatingCost(powerPerUnit, numberOfUnits, annualOperatingHours, laborCostForReplacement);
    }

    /**
     * 计算原设备上年运行费用
     *
     * @param laborCost         人工成本
     * @param lastYearEnergyUse 替代前年能源使用量
     * @param energyPrice       平均能源单价
     * @return
     */
    public double calLastYearFee(Double laborCost, Double lastYearEnergyUse, Double energyPrice) {
        // 上年运行费用（即原设备运行费用）= 上年能源使用量 * 平均能源单价 + 上年人工成本
        return energyPrice * lastYearEnergyUse + laborCost;
    }

    /**
     * 计算原设备年排碳量
     *
     * @param lastYearEnergyUse 替代前年能源使用量
     * @param d                 相关能源排放系数
     * @return
     */
    public double calLastYearFactor(Double lastYearEnergyUse, Double d) {
        return lastYearEnergyUse * d;
    }

    /**
     * 计算年减碳量
     * @param previousYearEnergyUsage 替代前原设备碳排放量
     * @param deviceElectric 电替代耗电量
     * @param electricEmission 电替代设备碳排放因子
     * @return 年减碳量
     */
    public  double calculateAnnualCarbonReduction(Double previousYearEnergyUsage, Double deviceElectric, Double electricEmission) {
        // 计算电替代设备年耗电量对应的标准煤量
        double coalEquivalentFromElectricity = deviceElectric * electricEmission;

        // 计算年减碳量
        return previousYearEnergyUsage - coalEquivalentFromElectricity;
    }

}
